<?php

/**
 * @file
 * Function implementations.
 */

/**
 * Try to detect if HTTPS was indeed used to connect.
 */
function _dropfort_update_detect_https() {
  global $is_https;
  // This may not be perfect but might be the best possible from within PHP.
  if (!empty($_SERVER['HTTPS']) and $_SERVER['HTTPS'] !== 'off' or $_SERVER['SERVER_PORT'] == 443 or $is_https) {
    return TRUE;
  }
  return FALSE;
}

/**
 * Wrapper function for generating a random key.
 */
function _dropfort_update_random_key($byte_count = 32) {
  if (VERSION < 7.24) {
    return drupal_hash_base64(drupal_random_bytes($byte_count));
  }
  else {
    return drupal_random_key($byte_count);
  }
}

/**
 * System status reporting.
 *
 * @see system_status()
 */
function _dropfort_update_system_status($check = FALSE) {
  $requirements = &drupal_static(__FUNCTION__);

  if (!isset($requirements) or empty($requirements)) {
    global $base_url;

    // Load .install files.
    include_once DRUPAL_ROOT . '/includes/install.inc';
    drupal_load_updates();

    // Check run-time requirements and status information.
    $requirements = module_invoke_all('requirements', 'runtime');
    usort($requirements, '_system_sort_requirements');

    if ($check) {
      $requirements = drupal_requirements_severity($requirements) == REQUIREMENT_ERROR;
    }
    else {
      $time = time();
      // Add the time we checked at.
      foreach ($requirements as $key => $requirement) {
        $requirements[$key]['lastchecked'] = $time;
        $requirements[$key] = str_replace('href="/', 'href="' . $base_url . '/', $requirements[$key]);
        $requirements[$key] = str_replace("href='/", "href='/" . $base_url . '/', $requirements[$key]);
      }
    }
  }

  return $requirements;
}
